@@ -41,6 +41,7 @@
 
 #include "tracker-config.h"
 #include "tracker-miner-files.h"
+#include "tracker-files-interface.h"
 
 #define ABOUT	  \
 	"Tracker " PACKAGE_VERSION "\n"
@@ -629,6 +630,8 @@ check_eligible (void)
 
 	domain_ontology = tracker_domain_ontology_new (domain_ontology_name, NULL, &error);
 	ontology = tracker_domain_ontology_get_ontology (domain_ontology);
+	tracker_domain_ontology_unref (domain_ontology);
+
 	sparql_conn = tracker_sparql_connection_new (0,
 	                                              NULL,
 	                                              ontology,
@@ -736,11 +739,9 @@ check_eligible (void)
 	}
 
 	g_free (path);
-	g_object_unref (config);
 	g_object_unref (file);
 	g_object_unref (miner_files);
 	g_object_unref (info);
-	tracker_domain_ontology_unref (domain_ontology);
 
 	return (indexable && parents_indexable) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
@@ -967,6 +968,7 @@ main (gint argc, gchar *argv[])
 	GMemoryMonitor *memory_monitor;
 #endif
 	gchar *domain_name, *dbus_name;
+	TrackerFilesInterface *files_interface;
 
 	main_loop = NULL;
 
@@ -1022,6 +1024,8 @@ main (gint argc, gchar *argv[])
 		return EXIT_FAILURE;
 	}
 
+	files_interface = tracker_files_interface_new (connection);
+
 	/* Initialize logging */
 	config = tracker_config_new ();
 
@@ -1188,6 +1192,8 @@ main (gint argc, gchar *argv[])
 		save_current_locale (domain_ontology);
 	}
 
+	g_object_unref (files_interface);
+
 	g_main_loop_unref (main_loop);
 	g_object_unref (config);
 
